@@ -8,6 +8,11 @@ from django.utils.translation import ugettext_lazy as _
 from cerberos.settings import MEMORY_FOR_FAILED_LOGINS
 import datetime
 
+try:
+    from django.utils import timezone
+except ImportError:
+    from datetime import datetime as timezone
+
 class FailedAccessAttempt(models.Model):
     created = models.DateTimeField(auto_now_add=True)
     modified = models.DateTimeField(auto_now=True)
@@ -21,6 +26,8 @@ class FailedAccessAttempt(models.Model):
             help_text=_(u'Failed logins for this IP'))
     locked = models.BooleanField(verbose_name=_(u'Locked'), default=False, db_index=True,
             help_text=_(u'Indicates if the IP has been locked out.'))
+    expired = models.BooleanField(verbose_name=_(u'Expired'), default=False, 
+            help_text=_(u'Indicates if the timeout has expired.'))
 
     get_data = models.TextField('GET Data')
     post_data = models.TextField('POST Data')
@@ -39,7 +46,7 @@ class FailedAccessAttempt(models.Model):
         Returns the time until this access attempt is forgotten.
         """
         if MEMORY_FOR_FAILED_LOGINS > 0:
-            now = datetime.datetime.now()
+            now = timezone.now()
             delta = now - self.modified
             time_remaining = MEMORY_FOR_FAILED_LOGINS - delta.seconds
             return time_remaining
